HTML_PARSER = 'html.parser'
DOMAIN = 'www.marketwatch.com'
BASE_URL = f'https://{DOMAIN}/investing/stock/'

BS, IS, CF = 'bs', 'is', 'cf'
FIN_STMT_URL_SUFFIX = {
    BS: '/balance-sheet',
    IS: '',
    CF: '/cash-flow'
}
END_DATE = 'End Date'

# All items marked `False` do not need to be scraped
# because they are calculated from other items (e.g. growth or ratios).
FINANCIAL_STATEMENT_ITEMS = {
    #################
    # Balance Sheet #
    #################
    "Cash & Short Term Investments": True,
    "Cash & Short Term Investments Growth": False,
    "Cash Only": True,
    "Short-Term Investments": True,
    "Cash & ST Investments / Total Assets": False,
    "Total Accounts Receivable": True,
    "Total Accounts Receivable Growth": False,
    "Accounts Receivables, Net": True,
    "Accounts Receivables, Gross": True,
    "Bad Debt/Doubtful Accounts": True,
    "Other Receivable": True,
    "Accounts Receivable Turnover": False,
    "Inventories": True,
    "Finished Goods": True,
    "Work in Progress": True,
    "Raw Materials": True,
    "Progress Payments & Other": True,
    "Other Current Assets": True,
    "Miscellaneous Current Assets": True,
    "Total Current Assets": True,
    "Net Property, Plant & Equipment": True,
    "Property, Plant & Equipment - Gross": True,
    "Buildings": True,
    "Land & Improvements": True,
    "Computer Software and Equipment": True,
    "Other Property, Plant & Equipment": True,
    "Accumulated Depreciation": True,
    "Total Investments and Advances": True,
    "Other Long-Term Investments": True,
    "Long-Term Note Receivables": True,
    "Intangible Assets": True,
    "Net Goodwill": True,
    "Net Other Intangibles": True,
    "Other Assets": True,
    "Total Assets": True,
    "Total Assets Growth": False,
    "ST Debt & Current Portion LT Debt": True,
    "Short Term Debt": True,
    "Current Portion of Long Term Debt": True,
    "Accounts Payable": True,
    "Accounts Payable Growth": False,
    "Income Tax Payable": True,
    "Other Current Liabilities": True,
    "Dividends Payable": True,
    "Accrued Payroll": True,
    "Miscellaneous Current Liabilities": True,
    "Total Current Liabilities": True,
    "Long-Term Debt": True,
    "Long-Term Debt excl. Capitalized Leases": True,
    "Non-Convertible Debt": True,
    "Convertible Debt": True,
    "Capitalized Lease Obligations": True,
    "Provision for Risks & Charges": True,
    "Deferred Taxes": True,
    "Deferred Taxes - Credits": True,
    "Deferred Taxes - Debit": True,
    "Other Liabilities": True,
    "Other Liabilities (excl. Deferred Income)": True,
    "Deferred Income": True,
    "Total Liabilities": True,
    "Non-Equity Reserves": True,
    "Total Liabilities / Total Assets": False,
    "Preferred Stock (Carrying Value)": True,
    "Redeemable Preferred Stock": True,
    "Non-Redeemable Preferred Stock": True,
    "Common Equity (Total)": True,
    "Common Equity / Total Assets": False,
    "Common Stock Par/Carry Value": True,
    "Retained Earnings": True,
    "ESOP Debt Guarantee": True,
    "Cumulative Translation Adjustment/Unrealized For. Exch. Gain": True,
    "Unrealized Gain/Loss Marketable Securities": True,
    "Revaluation Reserves": True,
    "Treasury Stock": True,
    "Total Shareholders' Equity": True,
    "Total Shareholders' Equity / Total Assets": False,
    "Accumulated Minority Interest": True,
    "Total Equity": True,
    "Liabilities & Shareholders' Equity": True,

    ####################
    # Income Statement #
    ####################
    "Sales/Revenue": True,
    "Sales Growth": False,
    "Cost of Goods Sold (COGS) incl. D&A": True,
    "COGS Growth": False,
    "COGS excluding D&A": True,
    "Depreciation & Amortization Expense": True,
    "Depreciation": True,
    "Amortization of Intangibles": True,
    "Gross Income": True,
    "Gross Income Growth": False,
    "Gross Profit Margin": False,
    "SG&A Expense": True,
    "SGA Growth": False,
    "Research & Development": True,
    "Other SG&A": True,
    "Other Operating Expense": True,
    "Unusual Expense": True,
    "EBIT after Unusual Expense": True,
    "Non Operating Income/Expense": True,
    "Non-Operating Interest Income": True,
    "Equity in Affiliates (Pretax)": True,
    "Interest Expense": True,
    "Interest Expense Growth": False,
    "Gross Interest Expense": True,
    "Interest Capitalized": True,
    "Pretax Income": True,
    "Pretax Income Growth": False,
    "Pretax Margin": False,
    "Income Tax": True,
    "Income Tax - Current Domestic": True,
    "Income Tax - Current Foreign": True,
    "Income Tax - Deferred Domestic": True,
    "Income Tax - Deferred Foreign": True,
    "Income Tax Credits": True,
    "Equity in Affiliates": True,
    "Other After Tax Income (Expense)": True,
    "Consolidated Net Income": True,
    "Minority Interest Expense": True,
    "Net Income": True,
    "Net Income Growth": False,
    "Net Margin Growth": False,
    "Extraordinaries & Discontinued Operations": True,
    "Extra Items & Gain/Loss Sale Of Assets": True,
    "Cumulative Effect - Accounting Chg": True,
    "Discontinued Operations": True,
    "Net Income After Extraordinaries": True,
    "Preferred Dividends": True,
    "Net Income Available to Common": True,
    "EPS (Basic)": True,
    "EPS (Basic) Growth": False,
    "Basic Shares Outstanding": True,
    "EPS (Diluted)": True,
    "EPS (Diluted) Growth": False,
    "Diluted Shares Outstanding": True,
    "EBITDA": True,
    "EBITDA Growth": False,
    "EBITDA Margin": False,

    #######################
    # Cash Flow Statement #
    #######################
    "Net Income before Extraordinaries": True,
    # "Net Income Growth": False,
    "Depreciation, Depletion & Amortization": True,
    "Depreciation and Depletion": True,
    "Amortization of Intangible Assets": True,
    "Deferred Taxes & Investment Tax Credit": True,
    # "Deferred Taxes": True,
    "Investment Tax Credit": True,
    "Other Funds": True,
    "Funds from Operations": True,
    "Extraordinaries": True,
    "Changes in Working Capital": True,
    "Receivables": True,
    # "Accounts Payable": True,
    "Other Assets/Liabilities": True,
    "Net Operating Cash Flow": True,
    "Net Operating Cash Flow Growth": False,
    "Net Operating Cash Flow / Sales": False,
    "Capital Expenditures": True,
    "Capital Expenditures Growth": False,
    "Capital Expenditures / Sales": False,
    "Capital Expenditures (Fixed Assets)": True,
    "Capital Expenditures (Other Assets)": True,
    "Net Assets from Acquisitions": True,
    "Sale of Fixed Assets & Businesses": True,
    "Purchase/Sale of Investments": True,
    "Purchase of Investments": True,
    "Sale/Maturity of Investments": True,
    "Other Uses": True,
    "Other Sources": True,
    "Net Investing Cash Flow": True,
    "Net Investing Cash Flow Growth": False,
    "Net Investing Cash Flow / Sales": False,
    "Cash Dividends Paid - Total": True,
    "Common Dividends": True,
    # "Preferred Dividends": True,
    "Change in Capital Stock": True,
    "Repurchase of Common & Preferred Stk.": True,
    "Sale of Common & Preferred Stock": True,
    "Proceeds from Stock Options": True,
    "Other Proceeds from Sale of Stock": True,
    "Issuance/Reduction of Debt, Net": True,
    "Change in Current Debt": True,
    "Change in Long-Term Debt": True,
    "Issuance of Long-Term Debt": True,
    "Reduction in Long-Term Debt": True,
    # "Other Funds": True,
    # "Other Uses": True,
    # "Other Sources": True,
    "Net Financing Cash Flow": True,
    "Net Financing Cash Flow Growth": False,
    "Net Financing Cash Flow / Sales": False,
    "Exchange Rate Effect": True,
    "Miscellaneous Funds": True,
    "Net Change in Cash": True,
    "Free Cash Flow": True,
    "Free Cash Flow Growth": False,
    "Free Cash Flow Yield": False,
}
